/*
 * Project name:
     Soft_I2C_Advanced (Simple test of Software_I2C library routines)
 * Copyright:
     (c) MikroElektronika, 2010.
 * Revision History:
     20100620:
       - initial release;
 * Description:
     This programme demonstrates usage of the Software I2C routines.
     It establishes I2C bus communication with 24C02 EEPROM chip, writes one byte
     of data on some location, then reads it and displays it on LCD display
 * Test configuration:
     MCU:             AT89S8253
                      http://www.atmel.com/dyn/resources/prod_documents/doc3286.pdf
     Dev.Board:       Easy8051 v6
                      http://www.mikroe.com/eng/products/view/329/easy8051-v6-development-system/
     Oscillator:      External, 10.0000 MHz
     Ext. Modules:    EEPROM extra board
                      http://www.mikroe.com/eng/products/view/137/eeprom-board/
                      Character LCD 2x16
                      http://www.mikroe.com/eng/products/view/277/various-components/
     SW:              mikroC PRO for 8051
                      http://www.mikroe.com/eng/products/view/232/mikroc-pro-for-8051/
 * NOTES:
     - Connect EEPROM extra board on PORT1.
     - Pull-up I2C communication line P1.0 and turn off PORT1 LEDs.
     - Turn on PORT0 LEDs (board specific).
     - Turn on LCD backlight on SW7.6
*/

#include "EEPROM_24C02.h"

// Lcd module connections
sbit LCD_RS at P2_0_bit;
sbit LCD_EN at P2_1_bit;

sbit LCD_D4 at P2_2_bit;
sbit LCD_D5 at P2_3_bit;
sbit LCD_D6 at P2_4_bit;
sbit LCD_D7 at P2_5_bit;
// End Lcd module connections

// Software I2C connections
sbit Soft_I2C_Scl at P1_0_bit;
sbit Soft_I2C_Sda at P1_1_bit;
// End Software I2C connections

char someData[] = "Software I2C";
char i ,tmpdata;

//  Main
void main() {

  EEPROM_24C02_Init();                      // performs I2C initialization

  P0 = 0xFF;

  Lcd_Init();                               // performs Lcd initialization
  Lcd_Cmd(_LCD_CLEAR);                      // clear Lcd
  Lcd_Cmd(_LCD_CURSOR_OFF);                 // set cursor off

  // Example for single-byte write
  i = 0;
  tmpdata = 1;
  while ((tmpdata = someData[i]) != 0) {
    i++;
    EEPROM_24C02_WrSingle(i, tmpdata);      // writes data, char by char, in the EEPROM
    Delay_ms(20);
    Lcd_Chr(1,i, tmpdata);                  // diplays data on the first row of the Lcd
  }
  EEPROM_24C02_WrSingle(i+1, 0);            // writes string termination
  Delay_ms(20);

  // Example for single-byte read
  i = 1;
  tmpdata = 1;
  while ((tmpdata = EEPROM_24C02_RdSingle(i)) != 0) {
    Lcd_Chr(2,i, tmpdata);                  // displays data from EEPROM on the second row of the Lcd
    Delay_ms(20);
    i++ ;
  }
}
