/*
 * Project name:
     EEPROM_Simple (Simple test of Software_I2C library routines)
 * Copyright:
     (c) MikroElektronika, 2010.
 * Revision History:
     20100620:
       - initial release;
 * Description:
     This programme demonstrates usage of the Software I2C routines.
     It establishes I2C bus communication with 24C02 EEPROM chip, writes one byte
     of data on some location, then reads it and displays it on PORT0.
 * Test configuration:
     MCU:             AT89S8253
                      http://www.atmel.com/dyn/resources/prod_documents/doc3286.pdf
     Dev.Board:       Easy8051 v6
                      http://www.mikroe.com/eng/products/view/329/easy8051-v6-development-system/
     Oscillator:      External, 10.0000 MHz
     Ext. Modules:    EEPROM extra board
                      http://www.mikroe.com/eng/products/view/137/eeprom-board/
     SW:              mikroC PRO for 8051
                      http://www.mikroe.com/eng/products/view/232/mikroc-pro-for-8051/
 * NOTES:
     - Connect EEPROM extra board on PORT1.
     - Pull-up I2C communication line P1.0 and turn off PORT1 LEDs.
     - Turn on PORT0 LEDs (board specific).
*/

// Software I2C connections
sbit Soft_I2C_Scl at P1_0_bit;
sbit Soft_I2C_Sda at P1_1_bit;
// End Software I2C connections

void main(){

  P0 = 0xFF;                     // configure PORT0 as output

  Soft_I2C_Init();               // initialize Soft_I2C communication
  Soft_I2C_Start();              // issue Soft_I2C start signal
  Soft_I2C_Write(0xA2);          // send byte via Soft_I2C (device address + W)
  Soft_I2C_Write(2);             // send byte (address of EEPROM location)
  Soft_I2C_Write(0xAA);          // send data (data to be written)
  Soft_I2C_Stop();               // issue Soft_I2C stop signal

  Delay_100ms();

  Soft_I2C_Start();              // issue Soft_I2C start signal
  Soft_I2C_Write(0xA2);          // send byte via Soft_I2C (device address + W)
  Soft_I2C_Write(2);             // send byte (data address)
  Soft_I2C_Start();              // issue Soft_I2C signal repeated start
  Soft_I2C_Write(0xA3);          // send byte (device address + R)
  P0 = Soft_I2C_Read(0u);        // read data (NO acknowledge)
  Soft_I2C_Stop();               // issue Soft_I2C stop signal
}

