/*
 * Project name:
     I2C_Advanced (Advanced I2C Example)
 * Copyright:
     (c) MikroElektronika, 2005-2010
 * Revision History:
     20080930:
       - initial release;
 * Description:
     This example features the advanced communication with the 24C02 EEPROM chip
     by introducing its own library of functions for this task: init, single
     write, single and sequential read. It performs write of a sequence of bytes
     (characters) into the EEPROM and writes this out at the first row on Lcd.
     Then, data read from EEPROM is performed and the result is displayed at the
     second row on Lcd.
 * Test configuration:
     MCU:             PIC16F887
                      http://ww1.microchip.com/downloads/en/DeviceDoc/41291F.pdf
     Dev.Board:       EasyPIC6
                      http://www.mikroe.com/eng/products/view/297/easypic6-development-system/
     Oscillator:      HS, 08.0000 MHz
     Ext. Modules:    EEPROM Board - ac:EEPROM
                      http://www.mikroe.com/eng/products/view/137/eeprom-board/
                      Character LCD 2x16 - ac:LCD
                      http://www.mikroe.com/eng/products/view/277/various-components/
     SW:              mikroC PRO for PIC
                      http://www.mikroe.com/eng/products/view/7/mikroc-pro-for-pic/
 * NOTES:
     - Connect EEPROM extra board on PORTC and Lcd.
     - Pull-up I2C communication lines (RC3 and RC4)
       place jumper J3 in upper position. (board specific)
     - Turn off PORTC LEDs (SW9.3). (board specific)
     - Turn on Lcd backlight on SW6.8 (board specific)*/
     
#include "EEPROM_24C02.h"

// LCD module connections
sbit LCD_RS at RB4_bit;
sbit LCD_EN at RB5_bit;
sbit LCD_D4 at RB0_bit;
sbit LCD_D5 at RB1_bit;
sbit LCD_D6 at RB2_bit;
sbit LCD_D7 at RB3_bit;

sbit LCD_RS_Direction at TRISB4_bit;
sbit LCD_EN_Direction at TRISB5_bit;
sbit LCD_D4_Direction at TRISB0_bit;
sbit LCD_D5_Direction at TRISB1_bit;
sbit LCD_D6_Direction at TRISB2_bit;
sbit LCD_D7_Direction at TRISB3_bit;
// End LCD module connections

char someData[] = "I2C mikroE";
char i ,tmpdata;

//  Main
void main() {

  EEPROM_24C02_Init();                      // performs I2C initialization
  TRISB = 0;
  PORTB = 0xFF;
  TRISB = 0xFF;
  ANSEL  = 0;                               // Configure AN pins as digital I/O
  ANSELH = 0;

  C1ON_bit = 0;
  C2ON_bit = 0;


  Lcd_Init();                               // performs Lcd initialization
  Lcd_Cmd(_LCD_CLEAR);                      // clear Lcd
  Lcd_Cmd(_LCD_CURSOR_OFF);                 // set cursor off

  // Example for single-byte write
  i = 0;
  tmpdata = 1;
  while ((tmpdata = someData[i]) != 0) {
    i++;
    EEPROM_24C02_WrSingle(i, tmpdata);      // writes data, char by char, in the EEPROM
    Delay_ms(20);
    Lcd_Chr(1,i, tmpdata);                  // diplays data on the first row of the Lcd
  }
  EEPROM_24C02_WrSingle(i+1, 0);            // writes string termination
  Delay_ms(20);

  // Example for single-byte read
  i = 1;
  tmpdata = 1;
  while ((tmpdata = EEPROM_24C02_RdSingle(i)) != 0) {
    Lcd_Chr(2,i, tmpdata);                  // displays data from EEPROM on the second row of the Lcd
    Delay_ms(20);
    i++ ;
  }

//  Example for sequential data read
//  Delay_ms(1000);
//  Lcd_Cmd(_LCD_CLEAR);
//  EEPROM_24C02_RdSeq(1, someData, 13);
//  Lcd_Out(2,1,someData);
}