/*
 * Project name:
     I2C_Advanced (Advanced I2C Example)
 * Copyright:
     (c) MikroElektronika, 2009.
 * Revision History:
     20091030:
       - initial release;
 * Description:
     This example features the advanced communication with the 24C02 EEPROM chip
     by introducing its own library of functions for this task: init, single
     write, single and sequential read. It performs write of a sequence of bytes
     (characters) into the EEPROM and writes this out at the first row on Lcd.
     Then, data read from EEPROM is performed and the result is displayed at the
     second row on Lcd.
 * Test configuration:
'     MCU:             dsPIC30F4013
'                      http://ww1.microchip.com/downloads/en/DeviceDoc/70138F.pdf
'     Dev.Board:       EASYdsPIC6
'                      http://www.mikroe.com/eng/products/view/434/easydspic6-development-system/
'     Oscillator:      XT-PLL8, 10.000MHz
'     Ext. Modules:    EEPROM board (24C02) connected to PORTF - ac:EEPROM
'                      http://www.mikroe.com/eng/products/view/137/eeprom-board/
'                      Character LCD 2x16 - ac:LCD
'                      http://www.mikroe.com/eng/products/view/277/various-components/
'     SW:              mikroC PRO for dsPIC30/33 and PIC24
'                      http://www.mikroe.com/eng/products/view/231/mikroc-pro-for-dspic30-33-and-pic24/
 * NOTES:
     - Use SmartADAPT to match the I2C pinout of the dsPIC30F4013 and EEPROM module. (board specific)
     - Pull-up I2C communication lines (RF2 and RF3)
       place jumper J5 in upper position. (board specific)
     - Turn off all PORT LEDs except PORTB at SW7. (board specific)
     - Turn ON LCD backlight at SW7. (board specific)
*/

#include "EEPROM_24C02.h"

// LCD module connections
sbit LCD_RS at LATD0_bit;
sbit LCD_EN at LATD1_bit;
sbit LCD_D4 at LATB0_bit;
sbit LCD_D5 at LATB1_bit;
sbit LCD_D6 at LATB2_bit;
sbit LCD_D7 at LATB3_bit;

sbit LCD_RS_Direction at TRISD0_bit;
sbit LCD_EN_Direction at TRISD1_bit;
sbit LCD_D4_Direction at TRISB0_bit;
sbit LCD_D5_Direction at TRISB1_bit;
sbit LCD_D6_Direction at TRISB2_bit;
sbit LCD_D7_Direction at TRISB3_bit;
// End LCD module connections

char someData[] = "I2C mikroE";
char i ,tmpdata;

//  Main
void main() {

  EEPROM_24C02_Init();                      // performs I2C initialization
  ADPCFG |= 0xFFFF;                         // initialize AN pins as digital
  Lcd_Init();                               // performs Lcd initialization
  Lcd_Cmd(_LCD_CLEAR);                      // clear Lcd
  Lcd_Cmd(_LCD_CURSOR_OFF);                 // set cursor off

  // Example for single-byte write
  i = 0;
  tmpdata = 1;
  while ((tmpdata = someData[i]) != 0) {
    i++;
    EEPROM_24C02_WrSingle(i, tmpdata);      // writes data, char by char, in the EEPROM
    Delay_ms(20);
    Lcd_Chr(1,i, tmpdata);                  // diplays data on the first row of the Lcd
  }
  EEPROM_24C02_WrSingle(i+1, 0);            // writes string termination
  Delay_ms(20);

  // Example for single-byte read
  i = 1;
  tmpdata = 1;
  while ((tmpdata = EEPROM_24C02_RdSingle(i)) != 0) {
    Lcd_Chr(2,i, tmpdata);                  // displays data from EEPROM on the second row of the Lcd
    Delay_ms(20);
    i++ ;
  }

  //  Example for sequential data read
//  Delay_ms(1000);
//  Lcd_Cmd(_LCD_CLEAR);
//  EEPROM_24C02_RdSeq(1, someData, 13);
//  Lcd_Out(2,1,someData);
}